<?php

namespace UnOcd\News\Policies;

use Litepie\User\Contracts\UserPolicy;
use UnOcd\News\Models\Set;

class SetPolicy
{

    /**
     * Determine if the given user can view the set.
     *
     * @param UserPolicy $user
     * @param Set $set
     *
     * @return bool
     */
    public function view(UserPolicy $user, Set $set)
    {
        if ($user->canDo('news.set.view') && $user->isAdmin()) {
            return true;
        }

        return $set->user_id == user_id() && $set->user_type == user_type();
    }

    /**
     * Determine if the given user can create a set.
     *
     * @param UserPolicy $user
     * @param Set $set
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('news.set.create');
    }

    /**
     * Determine if the given user can update the given set.
     *
     * @param UserPolicy $user
     * @param Set $set
     *
     * @return bool
     */
    public function update(UserPolicy $user, Set $set)
    {
        if ($user->canDo('news.set.edit') && $user->isAdmin()) {
            return true;
        }

        return $set->user_id == user_id() && $set->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given set.
     *
     * @param UserPolicy $user
     * @param Set $set
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Set $set)
    {
        return $set->user_id == user_id() && $set->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given set.
     *
     * @param UserPolicy $user
     * @param Set $set
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Set $set)
    {
        if ($user->canDo('news.set.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given set.
     *
     * @param UserPolicy $user
     * @param Set $set
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Set $set)
    {
        if ($user->canDo('news.set.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
